==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSortingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebSortingExpressionEventArgsDescription } from "./WebSortingExpressionEventArgsDescription";
/**
 * @hidden
 */
export let WebSortingExpressionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingExpressionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingExpressionEventArgsDescriptionMetadata.a == null) {
                WebSortingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingExpressionEventArgsDescriptionMetadata.c(WebSortingExpressionEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebSortingExpressionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSortingExpressionEventArgsDescriptionMetadata.a);
            WebSortingExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingExpressionEventArgs");
            a.item("Detail", "Array:WebSortingExpressionDescription:SortingExpression");
        }
        static d(a) {
            WebSortingExpressionEventArgsDescriptionMetadata.b(a);
            a.aa("WebSortingExpressionEventArgs", () => new WebSortingExpressionEventArgsDescription());
            a.z("WebSortingExpressionEventArgs", WebSortingExpressionEventArgsDescriptionMetadata.a);
        }
    }
    WebSortingExpressionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingExpressionEventArgsDescriptionMetadata, 'WebSortingExpressionEventArgsDescriptionMetadata');
    WebSortingExpressionEventArgsDescriptionMetadata.a = null;
    return WebSortingExpressionEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSortingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebSortingExpressionEventArgsDescription } from "./WebSortingExpressionEventArgsDescription";
/**
 * @hidden
 */
export let WebSortingExpressionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingExpressionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingExpressionEventArgsDescriptionMetadata.a == null) {
                WebSortingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingExpressionEventArgsDescriptionMetadata.c(WebSortingExpressionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebSortingExpressionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSortingExpressionEventArgsDescriptionMetadata.a);
            WebSortingExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingExpressionEventArgs");
            a.item("Detail", "Array:WebSortingExpressionDescription:SortingExpression");
        }
        static d(a) {
            WebSortingExpressionEventArgsDescriptionMetadata.b(a);
            a.ac("WebSortingExpressionEventArgs", () => new WebSortingExpressionEventArgsDescription());
            a.ab("WebSortingExpressionEventArgs", WebSortingExpressionEventArgsDescriptionMetadata.a);
        }
    }
    WebSortingExpressionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingExpressionEventArgsDescriptionMetadata, 'WebSortingExpressionEventArgsDescriptionMetadata');
    WebSortingExpressionEventArgsDescriptionMetadata.a = null;
    return WebSortingExpressionEventArgsDescriptionMetadata;
})();
